pub struct PackBitsCodecConfigurationV1 {
pub padding_encoding: Option<PackBitsPaddingEncoding>,
pub first_bit: Option<u64>,
pub last_bit: Option<u64>,
}Expand description
packbits codec configuration parameters (version 1.0 draft).
Example (Zarr V3)
{
"name": "packbits",
"configuration": {
"padding_encoding": "start_byte"
}
}Fields
padding_encoding: Option<PackBitsPaddingEncoding>Specifies how the number of padding bits is encoded, such that the number of decoded elements may be determined from the encoded representation alone.
first_bit: Option<u64>Specifies the index (starting from the least-significant bit) of the first bit to be encoded.
If omitted, or specified as null, defaults to 0.
last_bit: Option<u64>Specifies the index (starting from the least-significant bit) of the (inclusive) last bit to be encoded.
If omitted, or specified as null, defaults to N - 1, where N is the total number of bits per component of the data type.