pub struct ZstdCodecConfigurationV1 {
pub level: ZstdCompressionLevel,
pub checksum: bool,
}Expand description
zstd codec configuration parameters (version 1.0).
Fields
level: ZstdCompressionLevelThe compression level.
checksum: boolA boolean that indicates whether to store a checksum when writing that will be verified when reading.
Implementations
Sourceimpl ZstdCodecConfigurationV1
impl ZstdCodecConfigurationV1
Sourcepub const fn new(level: ZstdCompressionLevel, checksum: bool) -> Self
pub const fn new(level: ZstdCompressionLevel, checksum: bool) -> Self
Create a new zstd codec configuration given a ZstdCompressionLevel.